#
# spec file for package python-cloudpickle
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-cloudpickle
Version:        0.5.3
Release:        3.1
Summary:        Extended pickling support for Python objects
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/cloudpipe/cloudpickle
Source:         https://files.pythonhosted.org/packages/source/c/cloudpickle/cloudpickle-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
BuildRequires:  %{python_module curses}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module numpy >= 1.8.2}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tornado}
Requires:       python-curses
Requires:       python-numpy >= 1.8.2
Requires:       python-scipy
Requires:       python-tornado
%python_subpackages

%description
The cloudpickle package makes it possible to serialize Python constructs
not supported by the default pickle module from the Python standard
library.

cloudpickle is especially useful for cluster computing where Python
expressions are shipped over the network to execute on remote hosts,
possibly close to the data.

Among other things, cloudpickle supports pickling for lambda expressions,
functions and classes defined interactively in the __main__ module.

%prep
%setup -q -n cloudpickle-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Tests require very specific paths and py.test arguments
export PYTHONPATH='.:tests'
%python_expand py.test-%{$python_bin_suffix} -s

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Jul 18 2018 tchvatal@suse.com
- Fix runtime dependencies and raise numpy requirement
* Sat Jul 14 2018 arun@gmx.de
- update to version 0.5.3:
  * Fixed a crash in Python 2 when serializing non-hashable
    instancemethods of built-in types (issue #144).
  * itertools objects can also pickled (PR #156).
  * logging.RootLogger can be also pickled (PR #160).
* Sun Mar 11 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
* Wed Nov 22 2017 arun@gmx.de
- update to version 0.5.2:
  * Fixed a regression: AttributeError when loading pickles that hold
    a reference to a dynamically defined class from the __main__
    module. (issue #131).
  * Make it possible to pickle classes and functions defined in faulty
    modules that raise an exception when trying to look-up their
    attributes by name.
* Fri Nov 10 2017 toddrme2178@gmail.com
- Update to 0.5.1
  * Fixed `cloudpickle.__version__`.
- Update to 0.5.0
  * Use `pickle.HIGHEST_PROTOCOL` by default.
- Update to 0.4.2
  * Restored compatibility with pickles from 0.4.0.
  * Handle the `func.__qualname__` attribute.
- Update to 0.4.1
  * Fixed a crash when pickling dynamic classes whose `__dict__` attribute was
    defined as a [`property`](https://docs.python.org/3/library/functions.html#property).
    Most notably, this affected dynamic [namedtuples](https://docs.python.org/2/library/collections.html#namedtuple-factory-function-for-tuples-with-named-fields)
    in Python 2. (https://github.com/cloudpipe/cloudpickle/pull/113)
  * Cloudpickle now preserves the `__module__` attribute of functions (https://github.com/cloudpipe/cloudpickle/pull/118/).
  * Fixed a crash when pickling modules that don't have a `__package__` attribute (https://github.com/cloudpipe/cloudpickle/pull/116).
- Update to 0.4.0
  * Fix functions with empty cells
  * Allow pickling Logger objects
  * Fix crash when pickling dynamic class cycles
  * Ignore "None" mdoules added to sys.modules
  * Support WeakSets and ABCMeta instances
  * Remove non-standard `__transient__` support
  * Catch exception from `pickle.whichmodule()`
- Update to 0.3.1
  * Fix version information and ship a changelog
- Update to 0.3.0
  * Import submodules accessed by pickled functions
  * Support recursive functions inside closures
  * Fix `ResourceWarnings` and `DeprecationWarnings`
  * Assume modules with `__file__` attribute are not dynamic
* Thu May 11 2017 toddrme2178@gmail.com
- Implement singlespec version
- Fix source URL.
- Update to version 0.2.2
  * Support Python 3.6
  * Support Tornado Coroutines
  * Support builtin methods
- Update to version 0.2.1
  * Packaging fix
- Update to version 0.2.0
  * Support `method_descriptor`
  * Support unbound instancemethods
  * Fixes for PyPy3
  * More support for pickling dynamic imports
* Fri Jan 15 2016 toddrme2178@gmail.com
- Initial version
